@@ -441,8 +441,8 @@ void do_warn(SV* h, int rc, char* what) {
  *
  **************************************************************************/
 
-int MyConnect(dbh_t *sock, char* host, char* port, char* user,
-	      char* password, char* dbname, imp_dbh_t *imp_dbh) {
+int MyConnect(dbh_t *sock, char* unixSocket, char* host, char* port,
+	      char* user, char* password, char* dbname, imp_dbh_t *imp_dbh) {
     int portNr;
 
 #ifdef WIN32
@@ -481,7 +481,7 @@ int MyConnect(dbh_t *sock, char* host, char* port, char* user,
 	    mysql_options(*sock, MYSQL_OPT_COMPRESS, NULL);
 	}
 	return mysql_real_connect(*sock, host, user, password, dbname,
-				  portNr, NULL, 0) ?
+				  portNr, unixSocket, 0) ?
 	    TRUE : FALSE;
     }
 #else
@@ -531,6 +531,7 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
     char* port;
     char* user;
     char* password;
+    char* unixSocket = NULL;
     STRLEN len;
 
     sv = DBIc_IMP_DATA(imp_dbh);
@@ -582,6 +583,26 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
     } else {
         imp_dbh->compression = 0;
     }
+    if ((svp = hv_fetch(hv, "mysql_socket", 12, FALSE))  &&
+        *svp  &&  SvTRUE(*svp)) {
+        unixSocket = SvPV(*svp, na);
+    }
+#elif defined(IDX_TYPE)
+    if ((svp = hv_fetch(hv, "msql_configfile", 15, FALSE))  &&
+        *svp  &&  SvOK(*svp)) {
+        char* cf = SvPV(*svp, na);
+        if (dbis->debug >= 2) {
+            fprintf(DBILOGFP, "imp_dbh->MyLogin: Loading config file %s\n",
+                    cf);
+        }
+        if (msqlLoadConfigFile(cf) == -1) {
+            croak("Failed to load config file %s", cf);
+        }
+    }
+    if (port != 0  &&  dowarn) {
+        warn("Port settings are meaningless with mSQL 2." \
+             " Use msql_configfile instead.\n");
+    }
 #endif
 
     if (dbis->debug >= 2)
@@ -598,8 +619,8 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
     imp_dbh->svsock = &imp_dbh->mysql;
 #endif
 
-    return MyConnect(&imp_dbh->svsock, host, port, user, password, dbname,
-		     imp_dbh);
+    return MyConnect(&imp_dbh->svsock, unixSocket, host, port, user, password,
+		     dbname, imp_dbh);
 }
 
 
@@ -1553,6 +1574,9 @@ SV* dbd_st_FETCH_internal(SV* sth, int what, result_t res, int cacheit) {
 		sv = newSViv((int) native2sql(curField->type)->precision);
 		break;
 #endif
+	      default:
+		sv = &sv_undef;
+		break;
 	    }
 
 	    av_push(av, sv);
