@@ -123,7 +123,7 @@ sub Search ($$$$$) {
 		if ($::options->{verbose}) {
 		    print "Using $file in $dir.\n";
 		}
-		return (File::Basename::dirname($realfile), $dir);
+		return (File::Basename::dirname($realfile), $dir, $realfile);
 	    }
 	}
     }
@@ -149,7 +149,7 @@ sub Search ($$$$$) {
 	    if ($::options->{verbose}) {
 		print "Using $file in $gooddir.\n";
 	    }
-	    return (File::Basename::dirname($realfile), $gooddir);
+	    return (File::Basename::dirname($realfile), $gooddir, $realfile);
 	}
     }
 
@@ -184,7 +184,7 @@ sub SearchLibs ($$$$) {
 	unshift(@d, $self->{'libdir'});
     }
 
-    my($libdir, $gooddir) = $self->Search
+    my($libdir, $gooddir, $realfile) = $self->Search
 	($gooddirs, \@d, $files,
 	 "Where is your " . $self->{'description'}
 	 . " installed? Please tell me the directory that\n"
@@ -192,7 +192,7 @@ sub SearchLibs ($$$$) {
 
     $self->{'libdir'} = $gooddir;
     unshift(@$gooddirs, $gooddir);
-    ($libdir, $gooddir);
+    ($libdir, $gooddir, $realfile);
 }
 
 
@@ -219,6 +219,10 @@ sub CheckForLibGcc {
     # We try to fix this by always linking against libgcc.a. Unfortunately
     # it's somewhat hard to find out the path of this file ...
     #
+    if ($Config::Config{'osname'} eq 'netbsd') {
+	# Under NetBSD libc is nothing else than libgcc
+	return '';
+    }
     if ($Config::Config{'gccversion'} eq '') {
 	# This isn't gcc. Question is, does libmysqlclient.a require gcc?
 	require Symbol;
@@ -298,7 +302,7 @@ MSG
 sub Initialize ($) {
     my($self) = @_;
 
-    my @mysqldirs = ($^O =~ /mswin32/i) ? qw(C:/my/myodbc) :
+    my @mysqldirs = ($^O =~ /mswin32/i) ? qw(C:/mysql C:/my/myodbc) :
 	qw{/usr/local /usr/local/mysql /usr /usr/mysql /opt/mysql};
     my @gooddirs = ();
     my $gooddir;
@@ -316,21 +320,39 @@ sub Initialize ($) {
 	    (\@gooddirs, \@mysqldirs,
 	     ["include/mysql/mysql.h", "include/mysql.h"]);
     }
-    my $libdir;
+    my($libdir, $gooddir, $libfile);
     if (exists($ENV{'MYSQL_LIBDIR'})) {
 	$libdir = $ENV{'MYSQL_LIBDIR'};
     } else {
-	my @searchpath = ($^O =~ /mswin32/i) ?
-	    qw(lib/mysqlclient.lib lib_release/mysqlclient.lib
-	       lib_debug/mysqlclient.lib lib/lib.lib
-	       lib_release/lib.lib lib_debug/lib.lib) :
-	    qw(lib/mysql/libmysqlclient.a lib/mysql/libmysqlclient.so
-	       lib/libmysqlclient.a lib/libmysqlclient.so
-	       client/libmysqlclient.a client/libmysqlclient.so);
-	($libdir) = $self->SearchLibs(\@gooddirs, \@mysqldirs, \@searchpath);
+	my(@searchpath, $file, $dir);
+	if ($^O =~ /mswin32/i) {
+	    foreach $file (qw(mysqlclient.lib lib.lib)) {
+		foreach $dir (qw(lib/opt lib_release lib lib/debug
+				 lib_debug)) {
+		    push(@searchpath, "$dir/$file");
+		}
+	    }
+	} else {
+	    foreach $file (qw(libmysqlclient.a libmysqlclient.so)) {
+		foreach $dir (qw(lib/mysql lib)) {
+		    push(@searchpath, "$dir/$file");
+		}
+	    }
+	}
+	($libdir, $gooddir, $libfile)
+	    = $self->SearchLibs(\@gooddirs, \@mysqldirs, \@searchpath);
     }
 
-    my $sysliblist = "-L$libdir -lmysqlclient -lm";
+    my $sysliblist;
+    if ($::options->{'static'}) {
+	if ($libfile !~ /\.a/  &&  $libfile !~ /\.lib/) {
+	    die "Cannot use option -static with shared library file $libfile";
+	}
+	$self->{'static_libs'} = $libfile;
+    } else {
+	$sysliblist = "-L$libdir -lmysqlclient";
+    }
+    $sysliblist .= " -lm";
     my $defines = "-DDBD_MYSQL -DMyConnect=mysql_dr_connect"
 	. " -DMyLogin=mysql_dr_login";
     my $linkwith = "";
@@ -359,19 +381,22 @@ sub Initialize ($) {
 	      "the '", $Config::Config{'cccdlflags'}, "' flag",
 	      " of your C compiler.\n");
     } elsif ($^O =~ /mswin32/i) {
-	$defines .= " -D__WIN32__";
+	$defines .= " -DWIN32";
 
 	if (! -f "$libdir/mysqlclient.lib"  &&  -f "$libdir/lib.lib") {
 	    # Looks like we're using MyODBC.
 	    $sysliblist =~ s/-lmysqlclient/-llib/;
 	    $sysliblist .= " -lmysys -lstrings -lzlib";
+	    $defines .= " -DWIN32";
 	}
 
 	# For some reasons libc.lib is not linked against msvcrt.lib
 	# with VC++ ...
-	if ($Config::Config{'libs'} =~ /\bmsvcrt\.lib\b/  &&
-	    $Config::Config{'libs'} !~ /\blibc.lib\b/) {
-	    $sysliblist .= " -lc";
+	if ($Config::Config{'libs'} =~ /\bmsvcrt\.lib\b/) {
+	    $sysliblist .= " -lmsvcrt";
+	}
+	if ($Config::Config{'libs'} =~ /\blibc\.lib\b/) {
+	    $sysliblist .= " -llibc";
 	}
     }
 
