@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.03_04';
+$VERSION = '2.03_05';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -121,6 +121,48 @@ sub connect {
     DBD::mysql->_OdbcParse($dsn, $privateAttrHash,
 				  ['database', 'host', 'port']);
 
+    if (my $file = $privateAttrHash->{'mysql_configfile'}) {
+	require Symbol;
+	my $fh = Symbol::gensym();
+	if (!open($fh, "<$file")) {
+	    DBI::set_err($drh, "Unable to open config file $file: $!");
+	    return undef;
+	}
+	my $inSection;
+	while (defined(my $line = <$fh>)) {
+	    if ($line =~ /^\[(.*?)\]/) {
+		if ($inSection) {
+		    last;
+		} elsif ($1 eq 'perl'  ||  $1 eq 'client') {
+		    $inSection = 1;
+		}
+	    } elsif ($line =~ /^\s*(.*?)\s*=\s*(.*?)\s*$/) {
+		my $var = $1; my $val = $2;
+		if ($var eq 'host'  ||  $var eq 'hostname') {
+		    if (!$privateAttrHash->{'host'}) {
+			$privateAttrHash->{'host'} = $val;
+		    }
+		} elsif ($var eq 'password') {
+		    if (!$password) {
+			$password = $privateAttrHash->{'password'} = $val;
+		    }
+		} elsif ($var eq 'port') {
+		    if (!$privateAttrHash->{'port'}) {
+			$privateAttrHash->{'port'} = $val;
+		    }
+		} elsif ($var eq 'socket') {
+		    if (!$privateAttrHash->{'mysql_socket'}) {
+			$privateAttrHash->{'mysql_socket'} = $val;
+		    }
+		} elsif ($var eq 'user') {
+		    if (!$username) {
+			$username = $privateAttrHash->{'user'} = $val;
+		    }
+		}
+	    }
+	}
+    }
+
     if (!defined($this = DBI::_new_dbh($drh, {}, $privateAttrHash))) {
 	return undef;
     }
@@ -320,9 +362,9 @@ Interface (DBI)
     use DBI;
 
     $driver = "mSQL"; # or "mSQL1";
-    $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
+    $dsn = "DBI:$driver:database=$database;host=$hostname";
 
-    $dbh = DBI->connect($dsn,	undef, undef);
+    $dbh = DBI->connect($dsn, undef, undef);
 
         or
 
@@ -388,7 +430,6 @@ of the I<Msql-Mysql-modules> package.
     $driver = "mSQL";  #  or "mSQL1"
     $dsn = "DBI:$driver:$database";
     $dsn = "DBI:$driver:database=$database;host=$hostname";
-    $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
 
     $dbh = DBI->connect($dsn, undef, undef);
 
@@ -404,6 +445,12 @@ of the I<Msql-Mysql-modules> package.
 
 A C<database> must always be specified.
 
+=over 8
+
+=item host
+
+=item port
+
 The hostname, if not specified or specified as '', will default to an
 mysql or mSQL daemon running on the local machine on the default port
 for the UNIX socket.
@@ -411,14 +458,44 @@ for the UNIX socket.
 Should the mysql or mSQL daemon be running on a non-standard port number,
 you may explicitly state the port number to connect to in the C<hostname>
 argument, by concatenating the I<hostname> and I<port number> together
-separated by a colon ( C<:> ) character.
+separated by a colon ( C<:> ) character or by using the  C<port> argument.
+This doesn't work for mSQL 2: You have to create an alternative config
+file and load it using the msql_configfile attribute, see below.
+
+
+=item msql_configfile
+
+By default mSQL 2 loads its port settings and similar things from the
+file InstDir/msql.conf. This option allows you to specify another
+attribute, as in
+
+    DBI->connect("DBI:mSQL:test;msql_configfile=msql_test.conf");
+
+If the filename is not absolute, mSQL will search in certain other
+locations, see the documentation of the msqlLoadConfigFile() function
+in the mSQL manual for details.
+
+=item mysql_compression
 
 As of MySQL 3.22.3, a new feature is supported: If your DSN contains
 the option "mysql_compression=1", then the communication between client
 and server will be compressed.
 
+=item mysql_socket
+
+As of MySQL 3.21.15, it is possible to choose the Unix socket that is
+used for connecting to the server. This is done, for example, with
+
+    mysql_socket=/dev/mysql
+
+Usually there's no need for this option, unless you are using another
+location for the socket than that built into the client.
+
 =back
 
+=back
+
+
 =head2 Private MetaData Methods
 
 =over 4
